@@ -10,7 +10,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2003-2017  Craig Barratt
+#   Copyright (C) 2003-2019  Craig Barratt
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 #
 #========================================================================
 #
-# Version 4.1.3, released 3 Jun 2017.
+# Version 4.3.1, released 14 Jul 2019.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -38,6 +38,21 @@ package BackupPC::CGI::Queue;
 use strict;
 use BackupPC::CGI::Lib qw(:all);
 
+sub GetReqType
+{
+    my $req = shift(@_);
+    if ( $req->{restore} ) {
+        return "restore";
+    } elsif ( $req->{delete} ) {
+        return "delete (#$req->{num})";
+    } elsif ( $req->{archive} ) {
+        return "archive";
+    } else {
+        return "backup ($req->{backupType})" if ( $req->{backupType} );
+	return "backup";
+    }
+}
+
 sub action
 {
     my($strBg, $strUser, $strCmd);
@@ -52,28 +67,34 @@ sub action
     while ( @BgQueue ) {
         my $req = pop(@BgQueue);
         my($reqTime) = timeStamp2($req->{reqTime});
+	my $type = GetReqType($req);
         $strBg .= <<EOF;
 <tr><td> ${HostLink($req->{host})} </td>
-    <td align="center"> $reqTime </td>
+    <td align="center"> $type </td>
+    <td align="center" data-date_format="$Conf{CgiDateFormatMMDD}"> $reqTime </td>
     <td align="center"> $req->{user} </td></tr>
 EOF
     }
     while ( @UserQueue ) {
         my $req = pop(@UserQueue);
+	my $type = GetReqType($req);
         my $reqTime = timeStamp2($req->{reqTime});
         $strUser .= <<EOF;
 <tr><td> ${HostLink($req->{host})} </td>
-    <td align="center"> $reqTime </td>
+    <td align="center"> $type </td>
+    <td align="center" data-date_format="$Conf{CgiDateFormatMMDD}"> $reqTime </td>
     <td align="center"> $req->{user} </td></tr>
 EOF
     }
     while ( @CmdQueue ) {
         my $req = pop(@CmdQueue);
         my $reqTime = timeStamp2($req->{reqTime});
+	my $type = GetReqType($req);
         (my $cmd = $bpc->execCmd2ShellCmd(@{$req->{cmd}})) =~ s/$BinDir\///;
         $strCmd .= <<EOF;
 <tr><td> ${HostLink($req->{host})} </td>
-    <td align="center"> $reqTime </td>
+    <td align="center"> $type </td>
+    <td align="center" data-date_format="$Conf{CgiDateFormatMMDD}"> $reqTime </td>
     <td align="center"> $req->{user} </td>
     <td> $cmd </td></tr>
 EOF
