@@ -90,9 +90,12 @@ $Lang{BackupPC_Server_Status_General_Info}= <<EOF;
         <li>\$numUserQueue nevyzench dost o zlohu od uivatel,
         <li>\$numCmdQueue pending command requests,
         \$poolInfo
-        <li>Pool file system was recently at \$Info{DUlastValue}%
-            (\$DUlastTime), today\'s max is \$Info{DUDailyMax}% (\$DUmaxTime)
-            and yesterday\'s max was \$Info{DUDailyMaxPrev}%.
+        <li>Stav loit je \$Info{DUlastValue}%
+            (\$DUlastTime), dnen maximum je \$Info{DUDailyMax}% (\$DUmaxTime)
+                a verej maximum bylo \$Info{DUDailyMaxPrev}%.
+        <li>Inode stav loit je \$Info{DUInodelastValue}%
+            (\$DUlastTime), dnen maximum je \$Info{DUInodeDailyMax}% (\$DUInodemaxTime)
+                a verej maximum bylo \$Info{DUInodeDailyMaxPrev}%.
     </ul>
 </ul>
 EOF
@@ -103,7 +106,7 @@ $Lang{BackupPC_Server_Status} = <<EOF;
 <p>
 \${h2("Probhajc lohy")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td> Host </td>
     <td> Typ </td>
     <td> Uivatel </td>
@@ -122,7 +125,7 @@ $Lang{BackupPC_Server_Status} = <<EOF;
 
 \${h2("Selhn, kter vyaduj pozornost")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> Host </td>
     <td align="center"> Typ </td>
     <td align="center"> Uivatel </td>
@@ -145,7 +148,10 @@ $Lang{BackupPC_Summary} = <<EOF;
 <li>Tento stav byl vygenerovn v \$now.
 <li>Stav loit je \$Info{DUlastValue}%
     (\$DUlastTime), dnen maximum je \$Info{DUDailyMax}% (\$DUmaxTime)
-        a verej maximum bylo \$Info{DUDailyMaxPrev}%.
+    a verej maximum bylo \$Info{DUDailyMaxPrev}%.
+<li>Inode stav loit je \$Info{DUInodelastValue}%
+    (\$DUlastTime), dnen maximum je \$Info{DUInodeDailyMax}% (\$DUInodemaxTime)
+    a verej maximum bylo \$Info{DUInodeDailyMaxPrev}%.
 </ul>
 </p>
 
@@ -182,6 +188,7 @@ $Lang{BackupPC_Summary} = <<EOF;
 <table class="sortable" id="host_summary_nobackups" border cellpadding="3" cellspacing="1">
 <tr class="tableheader"><td> Host </td>
     <td align="center"> Uivatel </td>
+    <td align="center"> Poznmka </td>
     <td align="center"> #Pln </td>
     <td align="center"> Pln as (dn) </td>
     <td align="center"> Pln Velikost (GiB) </td>
@@ -376,8 +383,9 @@ $Lang{Backup_Queue_Summary} = <<EOF;
 <p>
 Nsledujc uivatel jsou momentln ve front:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Host </td>
+    <td> Action </td>
     <td> as do </td>
     <td> Uivatel </td></tr>
 \$strUser
@@ -387,8 +395,9 @@ Nsledujc uivatel jsou momentln ve front:
 <p>
 Nsledujc dosti v pozad jsou momentln ve front:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Host </td>
+    <td> Action </td>
     <td> as do </td>
     <td> Uivatel </td></tr>
 \$strBg
@@ -397,8 +406,9 @@ Nsledujc dosti v pozad jsou momentln ve front:
 <p>
 Nsledujc pkazy jsou momentln ve front:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Host </td>
+    <td> Action </td>
     <td> as do </td>
     <td> Uivatel </td>
     <td> Pkaz </td></tr>
@@ -427,7 +437,7 @@ $Lang{BackupPC__Log_File_History} = "BackupPC: Historie Log Souboru";
 $Lang{Log_File_History__hdr} = <<EOF;
 \${h1("Historie Log Souboru \$hdr")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Soubor </td>
     <td align="center"> Velikost </td>
     <td align="center"> as modifikace </td></tr>
@@ -439,7 +449,7 @@ EOF
 $Lang{Recent_Email_Summary} = <<EOF;
 \${h1("Pehled nedvnch email (azeno zptn)")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Pjemce </td>
     <td align="center"> Odeslatel </td>
     <td align="center"> as </td>
@@ -701,7 +711,7 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 <p>
 Kliknte na slo zlohy pro prohlen a obnoven zlohy.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> Backup# </td>
     <td align="center"> Typ </td>
     <td align="center"> Vyplnno </td>
@@ -719,7 +729,7 @@ Kliknte na slo zlohy pro prohlen a obnoven zlohy.
 \$restoreStr
 </p>
 \${h2("Pehled Xfer chyb")}
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Backup# </td>
     <td align="center"> Typ </td>
     <td align="center"> Pohled </td>
@@ -737,13 +747,13 @@ Existujc soubory jsou ty, kter jsou ji v loiti; nov jsou pidan
 do loit.
 Przn soubory a SMB chyby nejsou potny.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td colspan="2" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> Celkov </td>
     <td align="center" colspan="2"> Existujc soubory </td>
     <td align="center" colspan="2"> Nov soubory </td>
 </tr>
-<tr class="tableheader">
+<tr class="tableheader sortheader">
     <td align="center"> Zloha # </td>
     <td align="center"> Typ </td>
     <td align="center"> #Soubory </td>
@@ -762,12 +772,12 @@ Przn soubory a SMB chyby nejsou potny.
 Vkon komprese pro soubory, kter jsou ji v loiti a pro nov
 zkomprimovan soubory.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td colspan="3" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> Existujc soubory </td>
     <td align="center" colspan="3"> Nov soubory </td>
 </tr>
-<tr class="tableheader"><td align="center"> Zloha # </td>
+<tr class="tableheader sortheader"><td align="center"> Zloha # </td>
     <td align="center"> Typ </td>
     <td align="center"> rove komprese </td>
     <td align="center"> Velikost/MB </td>
@@ -1213,7 +1223,7 @@ $Lang{Restore_Summary} = <<EOF;
 \${h2("Obnovit souhrn")}
 <p>
 Klikni na obnoven pro vce detail.
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Obnoven # </td>
     <td align="center"> Vsledek </td>
     <td align="right"> Datum sputen</td>
@@ -1317,7 +1327,7 @@ Ujistte se, e je Vae PC pipojeno do st, a budete pt v kanceli.
 
 S pozdravem,
 BackupPC Genie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 # No recent backup
@@ -1345,7 +1355,7 @@ nebudou moci bti obnoveny, pokud se disk ve Vaem potai pokod.
 
 S pozdravem,
 BackupPC Genie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 # Old Outlook files
@@ -1375,7 +1385,7 @@ ke zjitn stavu zlohovn. Dokonen me trvat nkolik minut.
 
 S pozdravem,
 BackupPC Genie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 $Lang{howLong_not_been_backed_up} = "nebylo zlohovno spn";
@@ -1394,6 +1404,7 @@ Rychlost MB/sec: \$fullRate;
 Poet inkr: \$incrCnt;
 as inkr/Dn: \$incrAge;
 Stav: \$host_state;
+Zakzno: \$host_disabled;
 Posledn pokus: \$host_last_attempt;
 EOF
 
